from papermerge_restapi_client.paths.api_nodes_.get import ApiForget
from papermerge_restapi_client.paths.api_nodes_.post import ApiForpost


class ApiNodes(
    ApiForget,
    ApiForpost,
):
    pass
