# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from papermerge_restapi_client.paths.api_documents_document_id_upload_file_name import Api

from papermerge_restapi_client.paths import PathValues

path = PathValues.API_DOCUMENTS_DOCUMENT_ID_UPLOAD_FILE_NAME