from papermerge_restapi_client.paths.api_users_.get import ApiForget
from papermerge_restapi_client.paths.api_users_.post import ApiForpost


class ApiUsers(
    ApiForget,
    ApiForpost,
):
    pass
