from papermerge_restapi_client.paths.api_folders_.get import ApiForget
from papermerge_restapi_client.paths.api_folders_.post import ApiForpost


class ApiFolders(
    ApiForget,
    ApiForpost,
):
    pass
