# coding: utf-8

"""
    Papermerge REST API

    Document management system designed for digital archives  # noqa: E501

    The version of the OpenAPI document: 2.1.0b12
    Generated by: https://openapi-generator.tech
"""

from papermerge_restapi_client.paths.api_users_id_change_password_.post import UsersChangePasswordCreate
from papermerge_restapi_client.paths.api_users_.post import UsersCreate
from papermerge_restapi_client.paths.api_users_id_.delete import UsersDestroy
from papermerge_restapi_client.paths.api_users_.get import UsersList
from papermerge_restapi_client.paths.api_users_me_.get import UsersMeRetrieve
from papermerge_restapi_client.paths.api_users_id_.patch import UsersPartialUpdate
from papermerge_restapi_client.paths.api_users_id_.get import UsersRetrieve


class UsersApi(
    UsersChangePasswordCreate,
    UsersCreate,
    UsersDestroy,
    UsersList,
    UsersMeRetrieve,
    UsersPartialUpdate,
    UsersRetrieve,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
